@@ -156,6 +156,7 @@ struct activity irq_act = {
 	.f_render	= render_irq_stats,
 	.f_xml_print	= xml_print_irq_stats,
 	.f_json_print	= json_print_irq_stats,
+	.f_svg_print	= NULL,
 	.hdr_line	= "INTR;intr/s",
 	.name		= "A_IRQ",
 	.g_nr		= 0,
@@ -396,6 +397,7 @@ struct activity serial_act = {
 	.f_render	= render_serial_stats,
 	.f_xml_print	= xml_print_serial_stats,
 	.f_json_print	= json_print_serial_stats,
+	.f_svg_print	= NULL,
 	.hdr_line	= "TTY;rcvin/s;txmtin/s;framerr/s;prtyerr/s;brk/s;ovrun/s",
 	.name		= "A_SERIAL",
 	.g_nr		= 0,
@@ -1254,6 +1256,7 @@ struct activity pwr_wghfreq_act = {
 	.f_render	= render_pwr_wghfreq_stats,
 	.f_xml_print	= xml_print_pwr_wghfreq_stats,
 	.f_json_print	= json_print_pwr_wghfreq_stats,
+	.f_svg_print	= NULL,
 	.hdr_line	= "CPU;wghMHz",
 	.name		= "A_PWR_WGHFREQ",
 	.g_nr		= 0,
@@ -1287,6 +1290,7 @@ struct activity pwr_usb_act = {
 	.f_render	= render_pwr_usb_stats,
 	.f_xml_print	= xml_print_pwr_usb_stats,
 	.f_json_print	= json_print_pwr_usb_stats,
+	.f_svg_print	= NULL,
 	.hdr_line	= "manufact;product;BUS;idvendor;idprod;maxpower",
 	.name		= "A_PWR_USB",
 	.g_nr		= 0,
@@ -1304,7 +1308,7 @@ struct activity pwr_usb_act = {
 /* Filesystem usage activity */
 struct activity filesystem_act = {
 	.id		= A_FILESYSTEM,
-	.options	= AO_GRAPH_PER_ITEM,
+	.options	= AO_GRAPH_PER_ITEM + AO_MULTIPLE_OUTPUTS,
 	.magic		= ACTIVITY_MAGIC_BASE,
 	.group		= G_XDISK,
 #ifdef SOURCE_SADC
@@ -1321,7 +1325,8 @@ struct activity filesystem_act = {
 	.f_xml_print	= xml_print_filesystem_stats,
 	.f_json_print	= json_print_filesystem_stats,
 	.f_svg_print	= svg_print_filesystem_stats,
-	.hdr_line	= "FILESYSTEM;MBfsfree;MBfsused;%fsused;%ufsused;Ifree;Iused;%Iused",
+	.hdr_line	= "FILESYSTEM;MBfsfree;MBfsused;%fsused;%ufsused;Ifree;Iused;%Iused|"
+			  "MOUNTPOINT;MBfsfree;MBfsused;%fsused;%ufsused;Ifree;Iused;%Iused",
 	.name		= "A_FILESYSTEM",
 	.g_nr		= 4,
 #endif
