@@ -329,6 +329,25 @@ unsigned int get_devmap_major(void)
 	return dm_major;
 }
 
+/*
+ ***************************************************************************
+ * Returns whether S_TIME_FORMAT is set to ISO.
+ *
+ * RETURNS:
+ * TRUE if S_TIME_FORMAT is set to ISO, or FALSE otherwise.
+ ***************************************************************************
+ */
+int is_iso_time_fmt(void)
+{
+	static int is_iso = -1;
+	char *e;
+
+	if (is_iso < 0) {
+		is_iso = (((e = getenv(ENV_TIME_FMT)) != NULL) && !strcmp(e, K_ISO));
+	}
+	return is_iso;
+}
+
 /*
  ***************************************************************************
  * Print banner.
@@ -348,14 +367,13 @@ unsigned int get_devmap_major(void)
 int print_gal_header(struct tm *rectime, char *sysname, char *release,
 		     char *nodename, char *machine, int cpu_nr)
 {
-	char cur_date[64];
-	char *e;
+	char cur_date[TIMESTAMP_LEN];
 	int rc = 0;
 
 	if (rectime == NULL) {
 		strcpy(cur_date, "?/?/?");
 	}
-	else if (((e = getenv(ENV_TIME_FMT)) != NULL) && !strcmp(e, K_ISO)) {
+	else if (is_iso_time_fmt()) {
 		strftime(cur_date, sizeof(cur_date), "%Y-%m-%d", rectime);
 		rc = 1;
 	}
@@ -1008,16 +1026,16 @@ void init_colors(void)
  *
  * IN:
  * @num		Number of values to print.
- * @width	Output width.
+ * @wi		Output width.
  ***************************************************************************
 */
-void cprintf_u64(int num, int width, ...)
+void cprintf_u64(int num, int wi, ...)
 {
 	int i;
 	uint64_t val;
 	va_list args;
 
-	va_start(args, width);
+	va_start(args, wi);
 
 	for (i = 0; i < num; i++) {
 		val = va_arg(args, unsigned long long);
@@ -1027,7 +1045,7 @@ void cprintf_u64(int num, int width, ...)
 		else {
 			printf("%s", sc_int_stat);
 		}
-		printf(" %*"PRIu64, width, val);
+		printf(" %*"PRIu64, wi, val);
 		printf("%s", sc_normal);
 	}
 
@@ -1040,21 +1058,21 @@ void cprintf_u64(int num, int width, ...)
  *
  * IN:
  * @num		Number of values to print.
- * @width	Output width.
+ * @wi		Output width.
  ***************************************************************************
 */
-void cprintf_x(int num, int width, ...)
+void cprintf_x(int num, int wi, ...)
 {
 	int i;
 	unsigned int val;
 	va_list args;
 
-	va_start(args, width);
+	va_start(args, wi);
 
 	for (i = 0; i < num; i++) {
 		val = va_arg(args, unsigned int);
 		printf("%s", sc_int_stat);
-		printf(" %*x", width, val);
+		printf(" %*x", wi, val);
 		printf("%s", sc_normal);
 	}
 
@@ -1067,7 +1085,7 @@ void cprintf_x(int num, int width, ...)
  *
  * IN:
  * @num		Number of values to print.
- * @width	Output width.
+ * @wi		Output width.
  * @wd		Number of decimal places.
  ***************************************************************************
 */
@@ -1101,7 +1119,7 @@ void cprintf_f(int num, int wi, int wd, ...)
  *
  * IN:
  * @num		Number of values to print.
- * @width	Output width.
+ * @wi		Output width.
  * @wd		Number of decimal places.
  ***************************************************************************
 */
