@@ -69,7 +69,7 @@ int flags = 0;		/* Flag for common options and system state */
 unsigned int dm_major;	/* Device-mapper major number */
 
 long interval = 0;
-char timestamp[64];
+char timestamp[TIMESTAMP_LEN];
 
 struct sigaction alrm_act;
 
@@ -363,7 +363,8 @@ void presave_device_list(void)
 
 		/* Now save devices and group names in the io_hdr_stats structures */
 		for (i = 0; (i < dlist_idx) && (i < iodev_nr); i++, shi++, sdli++) {
-			strcpy(shi->name, sdli->dev_name);
+			strncpy(shi->name, sdli->dev_name, MAX_NAME_LEN);
+			shi->name[MAX_NAME_LEN - 1] = '\0';
 			shi->used = TRUE;
 			if (shi->name[0] == ' ') {
 				/* Current device name is in fact the name of a group */
@@ -382,7 +383,8 @@ void presave_device_list(void)
 		 * included in that group.
 		 */
 		shi += iodev_nr - 1;
-		strcpy(shi->name, group_name);
+		strncpy(shi->name, group_name, MAX_NAME_LEN);
+		shi->name[MAX_NAME_LEN - 1] = '\0';
 		shi->used = TRUE;
 		shi->status = DISK_GROUP;
 	}
@@ -983,7 +985,7 @@ void write_ext_stat(int curr, unsigned long long itv, int fctr,
 	 */
 	cprintf_pc(1, 6, 2,
 		   shi->used ? xds.util / 10.0 / (double) shi->used
-		             : xds.util / 10.0);	/* shi->used should never be null here */
+		             : xds.util / 10.0);	/* shi->used should never be zero here */
 	printf("\n");
 }
 
@@ -1201,7 +1203,7 @@ void write_stats(int curr, struct tm *rectime)
  * Main loop: Read I/O stats from the relevant sources and display them.
  *
  * IN:
- * @count	Number of lines of stats to print.
+ * @count	Number of reports to print.
  * @rectime	Current date and time.
  ***************************************************************************
  */
