@@ -275,6 +275,23 @@ int update_pid_array(unsigned int *pid_array_nr, unsigned int pid)
 	return i;
 }
 
+/*
+ ***************************************************************************
+ * Get pointer on task's command string.
+ *
+ * IN:
+ * @pst		Pointer on structure with process stats and command line.
+ ***************************************************************************
+ */
+char *get_tcmd(struct pid_stats *pst)
+{
+	if (DISPLAY_CMDLINE(pidflag) && strlen(pst->cmdline))
+		/* Option "-l" used */
+		return pst->cmdline;
+	else
+		return pst->comm;
+}
+
 /*
  ***************************************************************************
  * Display process command name or command line.
@@ -287,12 +304,8 @@ void print_comm(struct pid_stats *pst)
 {
 	char *p;
 
-	if (DISPLAY_CMDLINE(pidflag) && strlen(pst->cmdline)) {
-		p = pst->cmdline;
-	}
-	else {
-		p = pst->comm;
-	}
+	/* Get pointer on task's command string */
+	p = get_tcmd(pst);
 
 	if (pst->tgid) {
 		cprintf_s(IS_ZERO, "  |__%s\n", p);
@@ -528,8 +541,8 @@ int read_proc_pid_smap(unsigned int pid, struct pid_stats *pst, unsigned int tgi
  * @pst		Pointer on structure where command line has been saved.
  *
  * RETURNS:
- * 0 if command line has been successfully read, and 1 otherwise (the process
- * has terminated or its /proc/.../cmdline file is just empty).
+ * 0 if command line has been successfully read (even if the /proc/.../cmdline
+ * is just empty), and 1 otherwise (the process has terminated).
  *****************************************************************************
  */
 int read_proc_pid_cmdline(unsigned int pid, struct pid_stats *pst,
@@ -553,11 +566,8 @@ int read_proc_pid_cmdline(unsigned int pid, struct pid_stats *pst,
 
 	memset(line, 0, MAX_CMDLINE_LEN);
 
-	if ((len = fread(line, 1, MAX_CMDLINE_LEN - 1, fp)) == 0) {
-		/* Nothing to read doesn't mean that process no longer exists */
-		fclose(fp);
-		return 1;
-	}
+	len = fread(line, 1, MAX_CMDLINE_LEN - 1, fp);
+	fclose(fp);
 
 	for (i = 0; i < len; i++) {
 		if (line[i] == '\0') {
@@ -565,9 +575,14 @@ int read_proc_pid_cmdline(unsigned int pid, struct pid_stats *pst,
 		}
 	}
 
-	fclose(fp);
-	strncpy(pst->cmdline, line, MAX_CMDLINE_LEN - 1);
-	pst->cmdline[MAX_CMDLINE_LEN - 1] = '\0';
+	if (len) {
+		strncpy(pst->cmdline, line, MAX_CMDLINE_LEN - 1);
+		pst->cmdline[MAX_CMDLINE_LEN - 1] = '\0';
+	}
+	else {
+		/* proc/.../cmdline was empty */
+		pst->cmdline[0] = '\0';
+	}
 	return 0;
 }
 
@@ -1040,6 +1055,7 @@ int get_pid_to_display(int prev, int curr, int p, unsigned int activity,
 	int q, rc;
 	regex_t regex;
 	struct passwd *pwdent;
+	char *pc;
 
 	*pstc = st_pid_list[curr] + p;
 
@@ -1190,7 +1206,8 @@ int get_pid_to_display(int prev, int curr, int p, unsigned int activity,
 			/* Error in preparing regex structure */
 			return -1;
 
-		rc = regexec(&regex, (*pstc)->comm, 0, NULL, 0);
+		pc = get_tcmd(*pstc);	/* Get pointer on task's command string */
+		rc = regexec(&regex, pc, 0, NULL, 0);
 		regfree(&regex);
 
 		if (rc)
@@ -1207,7 +1224,8 @@ int get_pid_to_display(int prev, int curr, int p, unsigned int activity,
 				return -1;
 			}
 
-			rc = regexec(&regex, (*pstc)->comm, 0, NULL, 0);
+			pc = get_tcmd(*pstc);	/* Get pointer on task's command string */
+			rc = regexec(&regex, pc, 0, NULL, 0);
 			regfree(&regex);
 
 			if (rc) {
@@ -2318,7 +2336,7 @@ void write_stats_avg(int curr, int dis)
  */
 int write_stats(int curr, int dis)
 {
-	char cur_time[2][16];
+	char cur_time[2][TIMESTAMP_LEN];
 
 	/* Get previous timestamp */
 	if (is_iso_time_fmt()) {
