@@ -627,14 +627,20 @@ void print_report_hdr(unsigned int flags, struct tm *rectime,
  *
  * RETURNS:
  * Position of current network interface in array of sample statistics used
- * as reference.
+ * as reference, or -1 if it is a new interface (it was not present in array
+ * of stats used as reference).
+ *
+ * Note: A newly registered interface, if it is supernumerary, may make the
+ * last interface in the array going out of the list. Yet an interface going
+ * out of the list still exists in the /proc/net/dev file. Should it go back
+ * in the list (e.g. if some other interfaces have been unregistered) then
+ * its counters will jump as if starting from zero.
  ***************************************************************************
  */
-unsigned int check_net_dev_reg(struct activity *a, int curr, int ref,
-			       unsigned int pos)
+int check_net_dev_reg(struct activity *a, int curr, int ref, int pos)
 {
 	struct stats_net_dev *sndc, *sndp;
-	unsigned int index = 0;
+	int index = 0;
 
 	sndc = (struct stats_net_dev *) ((char *) a->buf[curr] + pos * a->msize);
 
@@ -707,23 +713,8 @@ unsigned int check_net_dev_reg(struct activity *a, int curr, int ref,
 		index++;
 	}
 
-	/* Network interface not found: Look for the first free structure */
-	for (index = 0; index < a->nr; index++) {
-		sndp = (struct stats_net_dev *) ((char *) a->buf[ref] + index * a->msize);
-		if (!strcmp(sndp->interface, ""))
-			break;
-	}
-	if (index >= a->nr) {
-		/* No free structure: Default is structure of same rank */
-		index = pos;
-	}
-
-	sndp = (struct stats_net_dev *) ((char *) a->buf[ref] + index * a->msize);
-	/* Since the name is not the same, reset all the structure */
-	memset(sndp, 0, STATS_NET_DEV_SIZE);
-	strncpy(sndp->interface, sndc->interface, MAX_IFACE_LEN - 1);
-
-	return  index;
+	/* This is a newly registered interface */
+	return -1;
 }
 
 /*
@@ -739,14 +730,13 @@ unsigned int check_net_dev_reg(struct activity *a, int curr, int ref,
  *
  * RETURNS:
  * Position of current network interface in array of sample statistics used
- * as reference.
+ * as reference, or -1 if it is a newly registered interface.
  ***************************************************************************
  */
-unsigned int check_net_edev_reg(struct activity *a, int curr, int ref,
-				unsigned int pos)
+int check_net_edev_reg(struct activity *a, int curr, int ref, int pos)
 {
 	struct stats_net_edev *snedc, *snedp;
-	unsigned int index = 0;
+	int index = 0;
 
 	snedc = (struct stats_net_edev *) ((char *) a->buf[curr] + pos * a->msize);
 
@@ -779,23 +769,8 @@ unsigned int check_net_edev_reg(struct activity *a, int curr, int ref,
 		index++;
 	}
 
-	/* Network interface not found: Look for the first free structure */
-	for (index = 0; index < a->nr; index++) {
-		snedp = (struct stats_net_edev *) ((char *) a->buf[ref] + index * a->msize);
-		if (!strcmp(snedp->interface, ""))
-			break;
-	}
-	if (index >= a->nr) {
-		/* No free structure: Default is structure of same rank */
-		index = pos;
-	}
-
-	snedp = (struct stats_net_edev *) ((char *) a->buf[ref] + index * a->msize);
-	/* Since the name is not the same, reset all the structure */
-	memset(snedp, 0, STATS_NET_EDEV_SIZE);
-	strncpy(snedp->interface, snedc->interface, MAX_IFACE_LEN - 1);
-
-	return  index;
+	/* This is a newly registered interface */
+	return -1;
 }
 
 /*
@@ -810,7 +785,8 @@ unsigned int check_net_edev_reg(struct activity *a, int curr, int ref,
  * @pos		Index on current disk.
  *
  * RETURNS:
- * Position of current disk in array of sample statistics used as reference.
+ * Position of current disk in array of sample statistics used as reference
+ * or -1 if it is a newly registered device.
  ***************************************************************************
  */
 int check_disk_reg(struct activity *a, int curr, int ref, int pos)
@@ -844,24 +820,8 @@ int check_disk_reg(struct activity *a, int curr, int ref, int pos)
 		index++;
 	}
 
-	/* Disk not found: Look for the first free structure */
-	for (index = 0; index < a->nr; index++) {
-		sdp = (struct stats_disk *) ((char *) a->buf[ref] + index * a->msize);
-		if (!(sdp->major + sdp->minor))
-			break;
-	}
-	if (index >= a->nr) {
-		/* No free structure found: Default is structure of same rank */
-		index = pos;
-	}
-
-	sdp = (struct stats_disk *) ((char *) a->buf[ref] + index * a->msize);
-	/* Since the device is not the same, reset all the structure */
-	memset(sdp, 0, STATS_DISK_SIZE);
-	sdp->major = sdc->major;
-	sdp->minor = sdc->minor;
-
-	return index;
+	/* This is a newly registered device */
+	return -1;
 }
 
 /*
@@ -1273,13 +1233,20 @@ int sa_open_read_magic(int *fd, char *dfile, struct file_magic *file_magic,
 
 	if ((n != FILE_MAGIC_SIZE) ||
 	    (file_magic->sysstat_magic != SYSSTAT_MAGIC) ||
-	    ((file_magic->format_magic != FORMAT_MAGIC) && !ignore) ||
-	    (file_magic->header_size <= MIN_FILE_HEADER_SIZE) ||
-	    (file_magic->header_size > MAX_FILE_HEADER_SIZE) ||
-	    ((file_magic->header_size < FILE_HEADER_SIZE) && !ignore)) {
+	    ((file_magic->format_magic != FORMAT_MAGIC) && !ignore)) {
 		/* Display error message and exit */
 		handle_invalid_sa_file(fd, file_magic, dfile, n);
 	}
+	if ((file_magic->sysstat_version > 10) ||
+	    ((file_magic->sysstat_version == 10) && (file_magic->sysstat_patchlevel >= 3))) {
+		/* header_size field exists only for sysstat versions 10.3.1 and later */
+		if ((file_magic->header_size <= MIN_FILE_HEADER_SIZE) ||
+		    (file_magic->header_size > MAX_FILE_HEADER_SIZE) ||
+		    ((file_magic->header_size < FILE_HEADER_SIZE) && !ignore)) {
+			/* Display error message and exit */
+			handle_invalid_sa_file(fd, file_magic, dfile, n);
+		}
+	}
 	if (file_magic->format_magic != FORMAT_MAGIC)
 		/* This is an old sa datafile format */
 		return -1;
@@ -1587,6 +1554,9 @@ int parse_sar_opt(char *argv[], int *opt, struct activity *act[],
 			set_bitmap(act[p]->bitmap->b_array, ~0,
 				   BITMAP_SIZE(act[p]->bitmap->b_size));
 			act[p]->opt_flags = AO_F_CPU_ALL;
+
+			p = get_activity_position(act, A_FILESYSTEM, EXIT_IF_NOT_FOUND);
+			act[p]->opt_flags = AO_F_FILESYSTEM;
 			break;
 
 		case 'B':
@@ -1613,6 +1583,9 @@ int parse_sar_opt(char *argv[], int *opt, struct activity *act[],
 				act[p]->opt_flags |= AO_F_MOUNT;
 				return 0;
 			}
+			else {
+				act[p]->opt_flags |= AO_F_FILESYSTEM;
+			}
 			break;
 
 		case 'H':
@@ -2273,7 +2246,7 @@ int print_special_record(struct record_header *record_hdr, unsigned int l_flags,
 			 struct file_magic *file_magic, struct file_header *file_hdr,
 			 struct activity *act[], struct report_format *ofmt)
 {
-	char cur_date[32], cur_time[32];
+	char cur_date[TIMESTAMP_LEN], cur_time[TIMESTAMP_LEN];
 	int dp = 1;
 	unsigned int new_cpu_nr;
 
@@ -2295,7 +2268,7 @@ int print_special_record(struct record_header *record_hdr, unsigned int l_flags,
 	else {
 		/* Set date and time strings to be displayed for current record */
 		set_record_timestamp_string(l_flags, record_hdr,
-					    cur_date, cur_time, 32, rectime);
+					    cur_date, cur_time, TIMESTAMP_LEN, rectime);
 	}
 
 	if (rtype == R_RESTART) {
