@@ -529,11 +529,9 @@ __tm_funct_t print_db_timestamp(void *parm, int action, char *cur_date,
  * @action	Action expected from current function.
  * @cur_date	Date string of current comment.
  * @cur_time	Time string of current comment.
- * @utc		True if @cur_time is expressed in UTC.
  * @itv		Interval of time with preceding record.
- *
- * OUT:
- * @tab		Number of tabulations.
+ * @file_hdr	System activity file standard header (unused here).
+ * @flags	Flags for common options.
  ***************************************************************************
  */
 __tm_funct_t print_xml_timestamp(void *parm, int action, char *cur_date,
@@ -563,11 +561,9 @@ __tm_funct_t print_xml_timestamp(void *parm, int action, char *cur_date,
  * @action	Action expected from current function.
  * @cur_date	Date string of current comment.
  * @cur_time	Time string of current comment.
- * @utc		True if @cur_time is expressed in UTC.
  * @itv		Interval of time with preceding record.
- *
- * OUT:
- * @tab		Number of tabulations.
+ * @file_hdr	System activity file standard header (unused here).
+ * @flags	Flags for common options.
  ***************************************************************************
  */
 __tm_funct_t print_json_timestamp(void *parm, int action, char *cur_date,
@@ -608,7 +604,7 @@ __tm_funct_t print_json_timestamp(void *parm, int action, char *cur_date,
  * @id_seq	Activity sequence (unused here).
  *
  * OUT:
- * @tab		Number of tabulations.
+ * @parm	Number of tabulations.
  ***************************************************************************
  */
 __printf_funct_t print_xml_header(void *parm, int action, char *dfile,
@@ -617,7 +613,7 @@ __printf_funct_t print_xml_header(void *parm, int action, char *dfile,
 				  struct activity *act[], unsigned int id_seq[])
 {
 	struct tm rectime, *loc_t;
-	char cur_time[32];
+	char cur_time[TIMESTAMP_LEN];
 	int *tab = (int *) parm;
 
 	if (action & F_BEGIN) {
@@ -675,7 +671,7 @@ __printf_funct_t print_xml_header(void *parm, int action, char *dfile,
  * @id_seq	Activity sequence (unused here).
  *
  * OUT:
- * @tab		Number of tabulations.
+ * @parm	Number of tabulations.
  ***************************************************************************
  */
 __printf_funct_t print_json_header(void *parm, int action, char *dfile,
@@ -684,7 +680,7 @@ __printf_funct_t print_json_header(void *parm, int action, char *dfile,
 				   struct activity *act[], unsigned int id_seq[])
 {
 	struct tm rectime, *loc_t;
-	char cur_time[32];
+	char cur_time[TIMESTAMP_LEN];
 	int *tab = (int *) parm;
 
 	if (action & F_BEGIN) {
@@ -745,7 +741,7 @@ __printf_funct_t print_hdr_header(void *parm, int action, char *dfile,
 {
 	int i, p;
 	struct tm rectime, *loc_t;
-	char cur_time[32];
+	char cur_time[TIMESTAMP_LEN];
 
 	/* Actions F_MAIN and F_END ignored */
 	if (action & F_BEGIN) {
