@@ -411,15 +411,26 @@ __print_funct_t xml_print_io_stats(struct activity *a, int curr, int tab,
 
 	xprintf(tab, "<io per=\"second\">");
 
+	/*
+	 * If we get negative values, this is probably because
+	 * one or more devices/filesystems have been unmounted.
+	 * We display 0.0 in this case though we should rather tell
+	 * the user that the value cannot be calculated here.
+	 */
 	xprintf(++tab, "<tps>%.2f</tps>",
+		sic->dk_drive < sip->dk_drive ? 0.0 :
 		S_VALUE(sip->dk_drive, sic->dk_drive, itv));
 
 	xprintf(tab, "<io-reads rtps=\"%.2f\" bread=\"%.2f\"/>",
-		S_VALUE(sip->dk_drive_rio,  sic->dk_drive_rio,  itv),
+		sic->dk_drive_rio < sip->dk_drive_rio ? 0.0 :
+		S_VALUE(sip->dk_drive_rio, sic->dk_drive_rio, itv),
+		sic->dk_drive_rblk < sip->dk_drive_rblk ? 0.0 :
 		S_VALUE(sip->dk_drive_rblk, sic->dk_drive_rblk, itv));
 
 	xprintf(tab, "<io-writes wtps=\"%.2f\" bwrtn=\"%.2f\"/>",
-		S_VALUE(sip->dk_drive_wio,  sic->dk_drive_wio,  itv),
+		sic->dk_drive_wio < sip->dk_drive_wio ? 0.0 :
+		S_VALUE(sip->dk_drive_wio, sic->dk_drive_wio, itv),
+		sic->dk_drive_wblk < sip->dk_drive_wblk ? 0.0 :
 		S_VALUE(sip->dk_drive_wblk, sic->dk_drive_wblk, itv));
 
 	xprintf(--tab, "</io>");
@@ -663,10 +674,12 @@ __print_funct_t xml_print_disk_stats(struct activity *a, int curr, int tab,
 				     unsigned long long itv)
 {
 	int i, j;
-	struct stats_disk *sdc,	*sdp;
+	struct stats_disk *sdc,	*sdp, sdpzero;
 	struct ext_disk_stats xds;
 	char *dev_name, *persist_dev_name;
 
+	memset(&sdpzero, 0, STATS_DISK_SIZE);
+
 	xprintf(tab++, "<disk per=\"second\">");
 
 	for (i = 0; i < a->nr; i++) {
@@ -677,7 +690,13 @@ __print_funct_t xml_print_disk_stats(struct activity *a, int curr, int tab,
 			continue;
 
 		j = check_disk_reg(a, curr, !curr, i);
-		sdp = (struct stats_disk *) ((char *) a->buf[!curr] + j * a->msize);
+		if (j < 0) {
+			/* This is a newly registered interface. Previous stats are zero */
+			sdp = &sdpzero;
+		}
+		else {
+			sdp = (struct stats_disk *) ((char *) a->buf[!curr] + j * a->msize);
+		}
 
 		/* Compute extended statistics values */
 		compute_ext_disk_stats(sdc, sdp, itv, &xds);
@@ -743,12 +762,14 @@ __print_funct_t xml_print_net_dev_stats(struct activity *a, int curr, int tab,
 					unsigned long long itv)
 {
 	int i, j;
-	struct stats_net_dev *sndc, *sndp;
+	struct stats_net_dev *sndc, *sndp, sndzero;
 	double rxkb, txkb, ifutil;
 
 	if (!IS_SELECTED(a->options) || (a->nr <= 0))
 		goto close_xml_markup;
 
+	memset(&sndzero, 0, STATS_NET_DEV_SIZE);
+
 	xml_markup_network(tab, OPEN_XML_MARKUP);
 	tab++;
 
@@ -757,10 +778,16 @@ __print_funct_t xml_print_net_dev_stats(struct activity *a, int curr, int tab,
 		sndc = (struct stats_net_dev *) ((char *) a->buf[curr] + i * a->msize);
 
 		if (!strcmp(sndc->interface, ""))
-			continue;
+			break;
 
 		j = check_net_dev_reg(a, curr, !curr, i);
-		sndp = (struct stats_net_dev *) ((char *) a->buf[!curr] + j * a->msize);
+		if (j < 0) {
+			/* This is a newly registered interface. Previous stats are zero */
+			sndp = &sndzero;
+		}
+		else {
+			sndp = (struct stats_net_dev *) ((char *) a->buf[!curr] + j * a->msize);
+		}
 
 		rxkb = S_VALUE(sndp->rx_bytes, sndc->rx_bytes, itv);
 		txkb = S_VALUE(sndp->tx_bytes, sndc->tx_bytes, itv);
@@ -808,11 +835,13 @@ __print_funct_t xml_print_net_edev_stats(struct activity *a, int curr, int tab,
 					 unsigned long long itv)
 {
 	int i, j;
-	struct stats_net_edev *snedc, *snedp;
+	struct stats_net_edev *snedc, *snedp, snedzero;
 
 	if (!IS_SELECTED(a->options) || (a->nr <= 0))
 		goto close_xml_markup;
 
+	memset(&snedzero, 0, STATS_NET_EDEV_SIZE);
+
 	xml_markup_network(tab, OPEN_XML_MARKUP);
 	tab++;
 
@@ -821,10 +850,16 @@ __print_funct_t xml_print_net_edev_stats(struct activity *a, int curr, int tab,
 		snedc = (struct stats_net_edev *) ((char *) a->buf[curr] + i * a->msize);
 
 		if (!strcmp(snedc->interface, ""))
-			continue;
+			break;
 
 		j = check_net_edev_reg(a, curr, !curr, i);
-		snedp = (struct stats_net_edev *) ((char *) a->buf[!curr] + j * a->msize);
+		if (j < 0) {
+			/* This is a newly registered interface. Previous stats are zero */
+			snedp = &snedzero;
+		}
+		else {
+			snedp = (struct stats_net_edev *) ((char *) a->buf[!curr] + j * a->msize);
+		}
 
 		xprintf(tab, "<net-edev iface=\"%s\" "
 			"rxerr=\"%.2f\" "
